@@ -1,7 +1,7 @@
 {
     'name': "Photovoltaic Management Extended",
-    'version': '13.0.1.0.3',
-    'depends': ['photovoltaic_mgmt'],
+    'version': '13.0.1.1.1',
+    'depends': ['photovoltaic_mgmt', 'photovoltaic_participant_liquidations'],
     'author': "Librecoop",
     'category': 'Sales',
     'description': """
